@@ -17,13 +17,13 @@ class Mortality:
     """
 
     configuration_defaults = {
-        'mortality': {
-            'mortality_rate': 0.01,
+        "mortality": {
+            "mortality_rate": 0.01,
         }
     }
 
     def __init__(self):
-        self.name = 'mortality'
+        self.name = "mortality"
 
     # noinspection PyAttributeOutsideInit
     def setup(self, builder: Builder):
@@ -39,12 +39,16 @@ class Mortality:
             Access to simulation tools and subsystems.
         """
         self.config = builder.configuration.mortality
-        self.population_view = builder.population.get_view(['alive'], query="alive == 'alive'")
-        self.randomness = builder.randomness.get_stream('mortality')
+        self.population_view = builder.population.get_view(
+            ["alive"], query="alive == 'alive'"
+        )
+        self.randomness = builder.randomness.get_stream("mortality")
 
-        self.mortality_rate = builder.value.register_rate_producer('mortality_rate', source=self.base_mortality_rate)
+        self.mortality_rate = builder.value.register_rate_producer(
+            "mortality_rate", source=self.base_mortality_rate
+        )
 
-        builder.event.register_listener('time_step', self.determine_deaths)
+        builder.event.register_listener("time_step", self.determine_deaths)
 
     def base_mortality_rate(self, index: pd.Index) -> pd.Series:
         """Computes the base mortality rate for every individual.
@@ -75,4 +79,4 @@ class Mortality:
         effective_probability = 1 - np.exp(-effective_rate)
         draw = self.randomness.get_draw(event.index)
         affected_simulants = draw < effective_probability
-        self.population_view.update(pd.Series('dead', index=event.index[affected_simulants]))
+        self.population_view.update(pd.Series("dead", index=event.index[affected_simulants]))
