@@ -10,13 +10,12 @@ For more information about time in the simulation, see the associated
 :ref:`concept note <time_concept>`.
 
 """
-from typing import Union, Callable
-from numbers import Number
 from datetime import datetime, timedelta
+from numbers import Number
+from typing import Callable, Union
 
 import pandas as pd
 
-
 Time = Union[pd.Timestamp, datetime, Number]
 Timedelta = Union[pd.Timedelta, timedelta, Number]
 
@@ -36,19 +35,19 @@ class SimulationClock:
     @property
     def time(self) -> Time:
         """The current simulation time."""
-        assert self._time is not None, 'No start time provided'
+        assert self._time is not None, "No start time provided"
         return self._time
 
     @property
     def stop_time(self) -> Time:
         """The time at which the simulation will stop."""
-        assert self._stop_time is not None, 'No stop time provided'
+        assert self._stop_time is not None, "No stop time provided"
         return self._stop_time
 
     @property
     def step_size(self) -> Timedelta:
         """The size of the next time step."""
-        assert self._step_size is not None, 'No step size provided'
+        assert self._step_size is not None, "No step size provided"
         return self._step_size
 
     def step_forward(self) -> None:
@@ -64,10 +63,10 @@ class SimpleClock(SimulationClock):
     """A unitless step-count based simulation clock."""
 
     configuration_defaults = {
-        'time': {
-            'start': 0,
-            'end': 100,
-            'step_size': 1,
+        "time": {
+            "start": 0,
+            "end": 100,
+            "step_size": 1,
         }
     }
 
@@ -85,25 +84,21 @@ class SimpleClock(SimulationClock):
 
 
 def get_time_stamp(time):
-    return pd.Timestamp(time['year'], time['month'], time['day'])
+    return pd.Timestamp(time["year"], time["month"], time["day"])
 
 
 class DateTimeClock(SimulationClock):
     """A date-time based simulation clock."""
 
     configuration_defaults = {
-        'time': {
-            'start': {
-                'year': 2005,
-                'month': 7,
-                'day': 2
+        "time": {
+            "start": {"year": 2005, "month": 7, "day": 2},
+            "end": {
+                "year": 2010,
+                "month": 7,
+                "day": 2,
             },
-            'end': {
-                'year': 2010,
-                'month': 7,
-                'day': 2,
-            },
-            'step_size': 1,  # Days
+            "step_size": 1,  # Days
         }
     }
 
@@ -115,7 +110,9 @@ class DateTimeClock(SimulationClock):
         time = builder.configuration.time
         self._time = get_time_stamp(time.start)
         self._stop_time = get_time_stamp(time.end)
-        self._step_size = pd.Timedelta(days=time.step_size // 1, hours=(time.step_size % 1) * 24)
+        self._step_size = pd.Timedelta(
+            days=time.step_size // 1, hours=(time.step_size % 1) * 24
+        )
 
     def __repr__(self):
         return "DateTimeClock()"
